#!/usr/bin/env bash

# Copyright (c) 2022 Battelle Energy Alliance, LLC.  All rights reserved.

# set up intel files prior to running zeek
#   - https://github.com/idaholab/Malcolm#zeek-intelligence-framework
#   - https://github.com/idaholab/Malcolm/issues/20
# used as the Zeek Dockerfile's entrypoint as well

set -uo pipefail
shopt -s nocasematch
ENCODING="utf-8"

ZEEK_DIR=${ZEEK_DIR:-"/opt/zeek"}
INTEL_DIR="${ZEEK_DIR}/share/zeek/site/intel"

# create directive to @load every subdirectory in /opt/zeek/share/zeek/site/intel
if [[ -d "${INTEL_DIR}" ]] && (( $(find "${INTEL_DIR}" -mindepth 1 -maxdepth 1 -type d 2>/dev/null | wc -l) > 0 )); then
    pushd "${INTEL_DIR}" >/dev/null 2>&1

    cat > __load__.zeek << EOF
# WARNING: This file is automatically generated.
# Do not make direct modifications here.
@load policy/integration/collective-intel
@load policy/frameworks/intel/seen
@load policy/frameworks/intel/do_notice

EOF
    LOOSE_INTEL_FILES=()

    # process subdirectories under INTEL_DIR
    for DIR in $(find . -mindepth 1 -maxdepth 1 -type d 2>/dev/null); do
        if [[ -f "${DIR}"/__load__.zeek ]]; then
            # this intel feed has its own load directive and should take care of itself
            echo "@load ${DIR}" >> __load__.zeek
        else
            # this directory contains "loose" intel files we'll need to load explicitly
            while IFS= read -r line; do
                LOOSE_INTEL_FILES+=( "$line" )
            done < <( find "${INTEL_DIR}/${DIR}" -type f 2>/dev/null )
        fi
    done

    # explicitly load all of the "loose" intel files in other subdirectories that didn't __load__.zeek themselves
    if (( ${#LOOSE_INTEL_FILES[@]} )); then
        echo >> __load__.zeek
        echo 'redef Intel::read_files += {' >> __load__.zeek
        for INTEL_FILE in "${LOOSE_INTEL_FILES[@]}"; do
            echo "  \"${INTEL_FILE}\"," >> __load__.zeek
        done
        echo '};' >> __load__.zeek
    fi

    popd >/dev/null 2>&1
fi

# start supervisor to spawn the other process(es) or whatever the default command is
exec "$@"
